import { customEvent } from '@genesislcap/foundation-events';
import { html, ref, repeat, when } from '@microsoft/fast-element';
/** @internal */
const datasource = (list) => {
    return list.isServerSideDatasource
        ? html `
        <grid-pro-server-side-datasource
          ${ref('datasource')}
          :deferredGridOptions=${(x) => x.gridOptions}
          criteria=${(x) => x.criteria}
          fields=${(x) => x.fields}
          is-snapshot=${(x) => x.isSnapshot}
          max-rows=${(x) => x.maxRows}
          max-view=${(x) => x.maxView}
          moving-view=${(x) => x.movingView}
          order-by=${(x) => x.orderBy}
          polling-interval=${(x) => x.pollingInterval}
          resource-name=${(x) => x.resourceName}
          :request=${(x) => x.request}
          reverse=${(x) => x.reverse}
        ></grid-pro-server-side-datasource>
      `
        : html `
        <grid-pro-client-side-datasource
          ${ref('datasource')}
          :deferredGridOptions=${(x) => x.gridOptions}
          criteria=${(x) => x.criteria}
          fields=${(x) => x.fields}
          is-snapshot=${(x) => x.isSnapshot}
          max-rows=${(x) => x.maxRows}
          max-view=${(x) => x.maxView}
          moving-view=${(x) => x.movingView}
          order-by=${(x) => x.orderBy}
          polling-interval=${(x) => x.pollingInterval}
          resource-name=${(x) => x.resourceName}
          :request=${(x) => x.request}
          reverse=${(x) => x.reverse}
        ></grid-pro-client-side-datasource>
      `;
};
export const getPrefixedList = (prefix) => html `
  <div class="container">
    ${when((x) => x.enableFilterBar, html `
        <${prefix}-filter-bar
          resource=${(x) => x.resourceName}
          only=${(x) => { var _a; return (_a = x.columns) === null || _a === void 0 ? void 0 : _a.map((colDef) => colDef.field).filter((field) => !!field); }}
          labels=${(x) => { var _a; return (_a = x.columns) === null || _a === void 0 ? void 0 : _a.map((colDef) => colDef.headerName || ''); }}
          target="datasource"
        ></${prefix}-filter-bar>
      `)}
    <${prefix}-grid-pro
      ${ref('grid')}
      auto-cell-renderer-by-type
      rowSelection="${(x) => x.rowSelection}"
      persist-column-state-key=${(x) => x.persistColumnStateKey}
      ?only-template-col-defs=${(x) => !!x.columns}
      readOnlyEdit="true"
      tooltipMouseTrack="true"
      tooltipShowDelay="0"
      async-add=${(x) => x.asyncAdd}
      async-remove=${(x) => x.asyncRemove}
      async-update=${(x) => x.asyncUpdate}
      enable-cell-flashing=${(x) => x.enableCellFlashing}
      enable-row-flashing=${(x) => x.enableRowFlashing}
      header-case-type=${(x) => x.headerCaseType}
      @rowClicked="${(x, ctx) => x.handleRowClicked(customEvent(ctx))}"
      @rowDblClicked="${(x, ctx) => x.handleRowDblClicked(customEvent(ctx))}"
      @cellContextMenu="${(x, ctx) => x.handleRowContextMenu(customEvent(ctx))}"
    >

      ${(x) => datasource(x)}

      ${repeat((x) => x.columns, html `
          <grid-pro-column :definition=${(x) => x}></grid-pro-column>
        `)}
      ${repeat((x) => x.actionButtonsConfig, html `
          <grid-pro-column :definition=${(x) => x}></grid-pro-column>
        `)}
    </${prefix}-grid-pro>
  </div>
`;
/** @internal */
export const listTemplate = html `
  ${(x) => getPrefixedList(x.prefix)}
`;
